==> estateplat-common-1.2.4-20200306.085956-270-sources.jar: cn/gtmap/estateplat/model/server/core/GdCq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * 过度草权
 * @author lst
 * @version V1.0, 15-5-6
 */
@Table(name = "gd_cq")
public class GdCq implements Serializable{
    @Id
    private String cqid;

    private String cdgyqk;
    private Date qlksrq;
    private Date qljsrq;
    private String tdsuqxz;
    private String yzyfs;
    private String cyzl;
    private Integer syzcl;
    private Double cbmj;
    private String zl;
    private String bz;
    private String cqzh;
    private String  dw;
    private Integer iszx;
    private String sjly;
    private Date gxrq;
    private String dwdm;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private String zxdaywh;//注销档案业务
    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getCqid() {
        return cqid;
    }

    public void setCqid(String cqid) {
        this.cqid = cqid;
    }

    public String getCdgyqk() {
        return cdgyqk;
    }

    public void setCdgyqk(String cdgyqk) {
        this.cdgyqk = cdgyqk;
    }

    public Date getQlksrq() {
        return qlksrq;
    }

    public void setQlksrq(Date qlksrq) {
        this.qlksrq = qlksrq;
    }

    public Date getQljsrq() {
        return qljsrq;
    }

    public void setQljsrq(Date qljsrq) {
        this.qljsrq = qljsrq;
    }

    public String getTdsuqxz() {
        return tdsuqxz;
    }

    public void setTdsuqxz(String tdsuqxz) {
        this.tdsuqxz = tdsuqxz;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

}

==> estateplat-common-1.2.4-20210909.071232-862-sources.jar: cn/gtmap/estateplat/model/server/core/GdCq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * 过度草权
 * @author lst
 * @version V1.0, 15-5-6
 */
@Table(name = "gd_cq")
public class GdCq implements Serializable{
    @Id
    private String cqid;

    private String cdgyqk;
    private Date qlksrq;
    private Date qljsrq;
    private String tdsuqxz;
    private String yzyfs;
    private String cyzl;
    private Integer syzcl;
    private Double cbmj;
    private String zl;
    private String bz;
    private String cqzh;
    private String  dw;
    private Integer iszx;
    private String sjly;
    private Date gxrq;
    private String dwdm;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private String zxdaywh;//注销档案业务
    private String zxfs;//注销方式  0或空为流程注销 1为手动注销

    public String getZxfs() {
        return zxfs;
    }

    public void setZxfs(String zxfs) {
        this.zxfs = zxfs;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getCqid() {
        return cqid;
    }

    public void setCqid(String cqid) {
        this.cqid = cqid;
    }

    public String getCdgyqk() {
        return cdgyqk;
    }

    public void setCdgyqk(String cdgyqk) {
        this.cdgyqk = cdgyqk;
    }

    public Date getQlksrq() {
        return qlksrq;
    }

    public void setQlksrq(Date qlksrq) {
        this.qlksrq = qlksrq;
    }

    public Date getQljsrq() {
        return qljsrq;
    }

    public void setQljsrq(Date qljsrq) {
        this.qljsrq = qljsrq;
    }

    public String getTdsuqxz() {
        return tdsuqxz;
    }

    public void setTdsuqxz(String tdsuqxz) {
        this.tdsuqxz = tdsuqxz;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

}
